.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

====================
RedTurtle Chefcookie
====================

Product's goal is to manage the insertion of tracking codes on the page like analytics, tagmanager, facebook, etc...
This allows to comply with latest gdpr's indications.

The plugin is based on chefcookie js plugin that you can find here: https://github.com/vielhuber/chefcookie/


Features
--------

In this first version you can use control panel to configure the plugin.


Examples
--------

This add-on can be seen in action at the following sites:

- http://www.unife.it/it


Translations
------------

This product has been translated into

- Italian


Installation
------------

Install redturtle.chefcookie by adding it to your buildout::

    [buildout]

    ...

    eggs =
        redturtle.chefcookie


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/RedTurtle/redturtle.chefcookie/issues
- Source Code: https://github.com/RedTurtle/redturtle.chefcookie


License
-------

The project is licensed under the GPLv2.
